Package Documentation
=====================

The **modlamp** package includes the following **modules**:

=========================== ==========================================================================================================
Module                      Characteristics
=========================== ==========================================================================================================
:mod:`modlamp.descriptors`  Module incorporating :class:`GlobalDescriptor` and :class:`PeptideDescriptor` for descriptor calculations.
:mod:`modlamp.sequences`    Module incorporating different classes for generating peptide sequences with different characteristics.
:mod:`modlamp.database`     Module incorporating functions to connect to the modlab in-house peptide database server.
:mod:`modlamp.datasets`     Module incorporating functions to load different peptide datasets used for ML classification tasks.
:mod:`modlamp.plot`         Module incorporating functions to visualize descriptor.
:mod:`modlamp.ml`           Module incorporating machine learning functions for training SVM or RF models on peptides.
:mod:`modlamp.wetlab`       Module incorporating classes for analysis of wetlab data like circular dichroism plots.
:mod:`modlamp.analysis`     Module incorporating the :class:`GlobalAnalysis` class for sequence library analysis and comparison.
:mod:`modlamp.core`         Module incorporating helper functions for other modules.
=========================== ==========================================================================================================


modlamp.descriptors
-------------------

.. automodule:: modlamp.descriptors
    :members:

modlamp.sequences
-----------------

.. automodule:: modlamp.sequences
    :members:

modlamp.database
----------------

.. automodule:: modlamp.database
    :members:

modlamp.datasets
----------------

.. automodule:: modlamp.datasets
    :members:

modlamp.plot
------------

.. automodule:: modlamp.plot
    :members:

modlamp.ml
----------

.. automodule:: modlamp.ml
    :members:

modlamp.wetlab
--------------

.. automodule:: modlamp.wetlab
    :members:

modlamp.analysis
----------------

.. automodule:: modlamp.analysis
    :members:

modlamp.core
------------

.. automodule:: modlamp.core
    :members:
